Using HostId instead of MacAddress when requesting timestamps from HostClockService
diff --git a/core/api/src/main/java/org/onlab/onos/net/host/HostClockService.java b/core/api/src/main/java/org/onlab/onos/net/host/HostClockService.java
index 49ef8f7..21de7a6 100644
--- a/core/api/src/main/java/org/onlab/onos/net/host/HostClockService.java
+++ b/core/api/src/main/java/org/onlab/onos/net/host/HostClockService.java
@@ -1,7 +1,7 @@
 package org.onlab.onos.net.host;
 
+import org.onlab.onos.net.HostId;
 import org.onlab.onos.store.Timestamp;
-import org.onlab.packet.MacAddress;
 
 /**
  * Interface for a logical clock service that issues per host timestamps.
@@ -9,9 +9,9 @@
 public interface HostClockService {
 
     /**
      * Returns a new timestamp for the specified host mac address.
      * @param hostMac host MAC address.
      * @return timestamp.
      */
-    public Timestamp getTimestamp(MacAddress hostMac);
+    public Timestamp getTimestamp(HostId hostId);
 }
@@ -9,9 +9,9 @@
 
     /**
-     * Returns a new timestamp for the specified host mac address.
-     * @param hostMac host MAC address.
+     * Returns a new timestamp for the specified host.
+     * @param hostId identifier for the host.
      * @return timestamp.
      */